searchData={"items":[{"type":"module","title":"FLAMEK8sBackend","doc":"","ref":"FLAMEK8sBackend.html"},{"type":"function","title":"FLAMEK8sBackend.with_elapsed_ms/1","doc":"","ref":"FLAMEK8sBackend.html#with_elapsed_ms/1"},{"type":"extras","title":"FlameK8sBackend","doc":"# FlameK8sBackend\n\nA [FLAME](https://github.com/phoenixframework/flame/tree/main) Backend for\nKubernetes. Manages pods as runners in the cluster the app is running in.\n\nThe current implementation is very basic and more like a proof of concept.\nMore configuration options (resources, etc.) will follow.","ref":"readme.html"},{"type":"extras","title":"Installation - FlameK8sBackend","doc":"```elixir\ndef deps do\n  [\n    {:flame_k8s_backend, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Requirements - FlameK8sBackend","doc":"#","ref":"readme.html#requirements"},{"type":"extras","title":"Env Variables - FlameK8sBackend","doc":"In order for the runners to be able to join the cluster, you need to configure\na few environment variables on your pod/deployment:\n\nThe `POD_NAME` and `POD_NAMESPACE` are used by the backend to get informations\nfrom your pod and use them for the runner pods (e.g. env variables).\n\n```yaml\napiVersion: apps/v1\nkind: Deployment\nspec:\n  selector:\n    matchLabels:\n      app: myapp\n  template:\n    spec:\n      metadata:\n        excluster: flame # see note in the headless service section below\n        app: myapp\n      containers:\n        - env:\n            - name: POD_NAME\n              valueFrom:\n                fieldRef:\n                  apiVersion: v1\n                  fieldPath: metadata.name\n            - name: POD_NAMESPACE\n              valueFrom:\n                fieldRef:\n                  apiVersion: v1\n                  fieldPath: metadata.namespace\n```\n\n#","ref":"readme.html#env-variables"},{"type":"extras","title":"RBAC - FlameK8sBackend","doc":"Your application needs run as a service account with permissions to manage\npods:\n\n```yaml\n---\napiVersion: v1\nkind: ServiceAccount\nmetadata:\n  name: myapp\n  namespace: michael-playground\n---\napiVersion: rbac.authorization.k8s.io/v1\nkind: Role\nmetadata:\n  namespace: michael-playground\n  name: pod-mgr\nrules:\n  - apiGroups: [\"\"]\n    resources: [\"pods\"]\n    verbs: [\"create\", \"get\", \"list\", \"delete\", \"patch\"]\n---\napiVersion: rbac.authorization.k8s.io/v1\nkind: RoleBinding\nmetadata:\n  name: myapp-pod-mgr\n  namespace: michael-playground\nsubjects:\n  - kind: ServiceAccount\n    name: myapp\n    namespace: michael-playground\nroleRef:\n  kind: Role\n  name: pod-mgr\n  apiGroup: rbac.authorization.k8s.io\n---\napiVersion: apps/v1\nkind: Deployment\nspec:\n  template:\n    spec:\n      serviceAccountName: flame-test\n```\n\n#","ref":"readme.html#rbac"},{"type":"extras","title":"Clustering - FlameK8sBackend","doc":"Your application needs to be able to form a cluster with your runners. One\nway to achieve this is to use [DNSCluster](https://hexdocs.pm/dns_cluster/DNSCluster.html).\n\n##","ref":"readme.html#clustering"},{"type":"extras","title":"ENV Variables - FlameK8sBackend","doc":"Pass the following variables to your pods\n\n```yaml\napiVersion: apps/v1\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - env:\n            - name: POD_IP\n              valueFrom:\n                fieldRef:\n                  apiVersion: v1\n                  fieldPath: status.podIP\n            - name: RELEASE_DISTRIBUTION\n              value: name\n            - name: RELEASE_NODE\n              value: flame_test@$(POD_IP)\n```\n\n##","ref":"readme.html#env-variables"},{"type":"extras","title":"Headless Service - FlameK8sBackend","doc":"A [headless service](https://kubernetes.io/docs/concepts/services-networking/service/#headless-services)\ntells `DNSCluster` the IP addresses of the runner pods.\n\n**NOTE: The selector you use on the service should NOT be the same label you're\nusing for the Replicaset of your deployment. Otherwise the Replicaset controller\nis going to see your runner pods as additional replicas of your application\nand immetiately terminate them!**\n\n```yaml\n---\napiVersion: v1\nkind: Service\nmetadata:\n  name: myapp-headless\n  namespace: michael-playground\nspec:\n  selector:\n    excluster: flame\n  type: ClusterIP\n  clusterIP: None\n```\n\n##","ref":"readme.html#headless-service"},{"type":"extras","title":"DNSCluster Setup - FlameK8sBackend","doc":"```elixir\ndefmodule MyApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @impl true\n  def start(_type, _opts) do\n    children =\n      [\n        # other children\n\n        # use the name of the headless service above for query\n        {DNSCluster, query: \"myapp-headless\", log: :debug}\n      ]\n\n    Supervisor.start_link(children,\n      strategy: :one_for_one,\n      name: KinoK8s.Supervisor\n    )\n  end\n```","ref":"readme.html#dnscluster-setup"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"<!-- #","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added | Changed | Deprecated | Removed | Fixed | Security --> - Changelog","doc":"## [0.1.0] - 2023-12-09\n\n- Very early stage implementation of a Kubernetes backend.","ref":"changelog.html#added-changed-deprecated-removed-fixed-security"}],"content_type":"text/markdown"}